package com.ruoyi.system.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.system.domain.ActSuppliesRole;
import com.ruoyi.system.domain.ActSuppliesRoleDetail;
import com.ruoyi.system.domain.ActSuppliesTemplate;
import org.apache.ibatis.annotations.Param;
import org.springframework.security.core.parameters.P;
import org.springframework.stereotype.Repository;

/**
 * 导入规则Mapper接口
 * 
 * @author dongjg
 * @date 2023-07-12
 */
@Repository
public interface ActSuppliesRoleMapper 
{
    /**
     * 查询导入规则
     * 
     * @param id 导入规则ID
     * @return 导入规则
     */
    public ActSuppliesRole selectActSuppliesRoleById(Integer id);

    /**
     * 查询导入规则列表
     * 
     * @param actSuppliesRole 导入规则
     * @return 导入规则集合
     */
    public List<ActSuppliesRole> selectActSuppliesRoleList(ActSuppliesRole actSuppliesRole);

    /**
     * 查询规则详情
     *
     * @param id 规则详情ID
     * @return 规则详情
     */
    public ActSuppliesRoleDetail selectActSuppliesRoleDetailById(Integer id);

    /**
     * 查询规则详情列表
     *
     * @param id 规则详情
     * @return 规则详情集合
     */
    public List<ActSuppliesRoleDetail> selectActSuppliesRoleDetailList(Integer id);

    /**
     * 新增导入规则
     * 
     * @param actSuppliesRole 导入规则
     * @return 结果
     */
    public int insertActSuppliesRole(ActSuppliesRole actSuppliesRole);

    /**
     * 修改导入规则
     * 
     * @param actSuppliesRole 导入规则
     * @return 结果
     */
    public int updateActSuppliesRole(ActSuppliesRole actSuppliesRole);

    public int updateActSuppliesRoleDetail(ActSuppliesRoleDetail actSuppliesRoleDetail);

    /**
     * 删除导入规则
     * 
     * @param id 导入规则ID
     * @return 结果
     */
    public int deleteActSuppliesRoleById(Integer id);

    /**
     * 批量删除导入规则
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteActSuppliesRoleByIds(Long[] ids);

    List<ActSuppliesTemplate> saveSid();

    int updateActSuppliesRole(Map<String, Object> paramMap);
    int setEnable(Map<String, Object> paramMap);
    int setDisable(Map<String, Object> paramMap);

    List<Integer> findall(Integer[] ids);
    List<Integer> find(Integer id);
    public int countByRoleName(ActSuppliesRole actSuppliesRole);


    Integer saveTemp(Long tempids);

    void updateRelease(ActSuppliesRole actSuppliesRole);

    String saveRoleName(Long id);

    int saveHistory(Long id);

    void updateReleaseoff(Long id);

    void updateReleaseoffone(Long id);

    void saveStatus(Integer[] ids);
}
