package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.ActSuppliesRole;
import com.ruoyi.system.domain.ActSuppliesRoleDetail;
import com.ruoyi.system.domain.ActSuppliesTemplate;
import io.lettuce.core.dynamic.annotation.Param;

/**
 * 导入规则Service接口
 * 
 * @author dongjg
 * @date 2023-07-12
 */

public interface IActSuppliesRoleService 
{
    /**
     * 查询导入规则
     * 
     * @param id 导入规则ID
     * @return 导入规则
     */
     ActSuppliesRole selectActSuppliesRoleById(Integer id);

    /**
     * 查询导入规则列表
     * 
     * @param actSuppliesRole 导入规则
     * @return 导入规则集合
     */
     List<ActSuppliesRole> selectActSuppliesRoleList(ActSuppliesRole actSuppliesRole);

    /**
     * 查询规则详情
     *
     * @param id 规则详情ID
     * @return 规则详情
     */
     ActSuppliesRoleDetail selectActSuppliesRoleDetailById(Integer id);

    /**
     * 查询规则详情列表
     *
     * @param id 规则详情
     * @return 规则详情集合
     */
     List<ActSuppliesRoleDetail> selectActSuppliesRoleDetailList(Integer id);

    /**
     * 新增导入规则
     * 
     * @param actSuppliesRole 导入规则
     * @return 结果
     */
     int insertActSuppliesRole(ActSuppliesRole actSuppliesRole);

    /**
     * 修改导入规则
     * 
     * @param actSuppliesRole 导入规则
     * @return 结果
     */
     int updateActSuppliesRole(ActSuppliesRole actSuppliesRole);

     int updateActSuppliesRoleDetail(ActSuppliesRoleDetail actSuppliesRoleDetail);

    /**
     * 批量删除导入规则
     * 
     * @param ids 需要删除的导入规则ID
     * @return 结果
     */
    public int deleteActSuppliesRoleByIds(Long[] ids);

    /**
     * 删除导入规则信息
     * 
     * @param id 导入规则ID
     * @return 结果
     */
     int deleteActSuppliesRoleById(Integer id);

    List<ActSuppliesTemplate> saveSid();
    /**
     * 启用物料细分类管理
     *
     * @param id  尝试启用物料细分类管理的id
     * @return
     */
    int setEnable(@Param("id") Long id, @Param("status") Integer status);


    /**
     * 禁用
     *
     * @param id  尝试禁用物料细分类管理的id
     */
    int setDisable(@Param("id") Long id, @Param("status") Integer status);

    List<Integer> findall(Integer[] ids);
    List<Integer> find(Integer id);

    List<String> releaseRS(Long[] ids ,Long[] tempids);

    int offShelfRS(Long[] ids);
}
